@@ -14,16 +14,26 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
+
 #pragma once
 
-#include "UserDefineResource.h"
-#include "ControlsTab.h"
-#include "ColourPicker.h"
-#include "Parameters.h"
-#include "URLCtrl.h"
-#include "SciLexer.h"
+#include <windows.h>
+
+#include <cwchar>
+#include <memory>
+#include <string>
 #include <unordered_map>
 
+#include <SciLexer.h>
+
+#include "ColourPicker.h"
+#include "ControlsTab.h"
+#include "Parameters.h"
+#include "StaticDialog.h"
+#include "URLCtrl.h"
+#include "UserDefineResource.h"
+#include "Window.h"
+
 class ScintillaEditView;
 class UserLangContainer;
 struct Style;
@@ -359,7 +369,7 @@ protected :
 private :
     ControlsTab _ctrlTab;
     WindowVector _wVector;
-    UserLangContainer *_pCurrentUserLang = nullptr;
+	std::unique_ptr<UserLangContainer> _pCurrentUserLang = nullptr;
     FolderStyleDialog       _folderStyleDlg;
     KeyWordsStyleDialog     _keyWordsStyleDlg;
     CommentStyleDialog      _commentStyleDlg;
@@ -369,6 +379,9 @@ private :
     int _currentHight = 0;
     int _yScrollPos = 0;
     int _prevHightVal = 0;
+
+	using Window::init;
+
     void getActualPosSize() {
         ::GetWindowRect(_hSelf, &_dlgPos);
         _dlgPos.right -= _dlgPos.left;
@@ -420,24 +433,23 @@ private :
 	std::wstring _restrictedChars;
     int _txtLen = 0;
 	bool _shouldGotoCenter = false;
+
+	using Window::init;
 };
 
 class StylerDlg : public StaticDialog
 {
 public:
-    StylerDlg(HINSTANCE hInst, HWND parent, int stylerIndex = 0, int enabledNesters = -1):
-        _stylerIndex(stylerIndex), _enabledNesters(enabledNesters) {
-        Window::init(hInst, parent);
-        _pFgColour = new ColourPicker;
-        _pBgColour = new ColourPicker;
-        _initialStyle = SharedParametersDialog::_pUserLang->_styles.getStyler(stylerIndex);
-    }
+	StylerDlg(HINSTANCE hInst, HWND parent, int stylerIndex = 0, int enabledNesters = -1)
+		: _stylerIndex(stylerIndex), _enabledNesters(enabledNesters)
+		, _pFgColour(std::make_unique<ColourPicker>()), _pBgColour(std::make_unique<ColourPicker>())
+		, _initialStyle(SharedParametersDialog::_pUserLang->_styles.getStyler(stylerIndex)) {
+		Window::init(hInst, parent);
+	}
 
     ~StylerDlg() override {
         _pFgColour->destroy();
         _pBgColour->destroy();
-        delete _pFgColour;
-        delete _pBgColour;
     }
 
     void destroy() override {}
@@ -452,9 +464,11 @@ protected:
 private:
     int _stylerIndex = 0;
     int _enabledNesters = 0;
-    ColourPicker * _pFgColour = nullptr;
-    ColourPicker * _pBgColour = nullptr;
+	std::unique_ptr<ColourPicker> _pFgColour = nullptr;
+	std::unique_ptr<ColourPicker> _pBgColour = nullptr;
     Style _initialStyle;
 
+	using Window::init;
+
     void move2CtrlRight(HWND hwndDlg, int ctrlID, HWND handle2Move, int handle2MoveWidth, int handle2MoveHeight);
 };
