@@ -14,23 +14,25 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-#include <shlwapi.h>
-#include "ScintillaEditView.h"
+
 #include "functionParser.h"
-#include "BoostRegexSearch.h"
 
-using namespace std;
+#include <windows.h>
 
-FunctionParsersManager::~FunctionParsersManager()
-{
-	for (size_t i = 0, len = L_EXTERNAL + nbMaxUserDefined; i < len; ++i)
-	{
-		if (_parsers[i] != nullptr)
-			delete _parsers[i];
-	}
-}
+#include <memory>
+#include <string>
+#include <utility>
+#include <vector>
 
-bool FunctionParsersManager::init(const wstring& xmlDirPath, const wstring& xmlInstalledPath, ScintillaEditView ** ppEditView)
+#include <BoostRegexSearch.h>
+#include <Scintilla.h>
+
+#include "Common.h"
+#include "Notepad_plus_msgs.h"
+#include "NppXml.h"
+#include "ScintillaEditView.h"
+
+bool FunctionParsersManager::init(const std::wstring& xmlDirPath, const std::wstring& xmlInstalledPath, ScintillaEditView** ppEditView)
 {
 	_ppEditView = ppEditView;
 	_xmlDirPath = xmlDirPath;
@@ -45,56 +47,59 @@ bool FunctionParsersManager::init(const wstring& xmlDirPath, const wstring& xmlI
 		return false;
 }
 
-bool FunctionParsersManager::getZonePaserParameters(TiXmlNode *classRangeParser, wstring &mainExprStr, wstring &openSymboleStr, wstring &closeSymboleStr, std::vector<wstring> &classNameExprArray, wstring &functionExprStr, std::vector<wstring> &functionNameExprArray)
+bool FunctionParsersManager::getZonePaserParameters(
+	const NppXml::Element& classRangeParser,
+	std::string& mainExprStr,
+	std::string& openSymboleStr,
+	std::string& closeSymboleStr,
+	std::vector<std::string>& classNameExprArray,
+	std::string& functionExprStr,
+	std::vector<std::string>& functionNameExprArray
+)
 {
-	const wchar_t *mainExpr = NULL;
-	const wchar_t *openSymbole = NULL;
-	const wchar_t *closeSymbole = NULL;
-	const wchar_t *functionExpr = NULL;
-
-	mainExpr = (classRangeParser->ToElement())->Attribute(L"mainExpr");
+	const char* mainExpr = NppXml::attribute(classRangeParser, "mainExpr");
 	if (!mainExpr || !mainExpr[0])
 		return false;
 	mainExprStr = mainExpr;
 
-	openSymbole = (classRangeParser->ToElement())->Attribute(L"openSymbole");
+	const char* openSymbole = NppXml::attribute(classRangeParser, "openSymbole");
 	if (openSymbole && openSymbole[0])
 		openSymboleStr = openSymbole;
 
-	closeSymbole = (classRangeParser->ToElement())->Attribute(L"closeSymbole");
+	const char* closeSymbole = NppXml::attribute(classRangeParser, "closeSymbole");
 	if (closeSymbole && closeSymbole[0])
 		closeSymboleStr = closeSymbole;
 
-	TiXmlNode *classNameParser = classRangeParser->FirstChild(L"className");
+	NppXml::Element classNameParser = NppXml::firstChildElement(classRangeParser, "className");
 	if (classNameParser)
 	{
-		for (TiXmlNode *childNode2 = classNameParser->FirstChildElement(L"nameExpr");
+		for (NppXml::Element childNode2 = NppXml::firstChildElement(classNameParser, "nameExpr");
 			childNode2;
-			childNode2 = childNode2->NextSibling(L"nameExpr") )
+			childNode2 = NppXml::nextSiblingElement(childNode2, "nameExpr"))
 		{
-			const wchar_t *expr = (childNode2->ToElement())->Attribute(L"expr");
+			const char* expr = NppXml::attribute(childNode2, "expr");
 			if (expr && expr[0])
 				classNameExprArray.push_back(expr);
 		}
 	}
 
-	TiXmlNode *functionParser = classRangeParser->FirstChild(L"function");
+	NppXml::Element functionParser = NppXml::firstChildElement(classRangeParser, "function");
 	if (!functionParser)
 		return false;
 
-	functionExpr = (functionParser->ToElement())->Attribute(L"mainExpr");
+	const char* functionExpr = NppXml::attribute(functionParser, "mainExpr");
 	if (!functionExpr || !functionExpr[0])
 		return false;
 	functionExprStr = functionExpr;
 
-	TiXmlNode *functionNameParser = functionParser->FirstChild(L"functionName");
+	NppXml::Element functionNameParser = NppXml::firstChildElement(functionParser, "functionName");
 	if (functionNameParser)
 	{
-		for (TiXmlNode *childNode3 = functionNameParser->FirstChildElement(L"funcNameExpr");
+		for (NppXml::Element childNode3 = NppXml::firstChildElement(functionNameParser, "funcNameExpr");
 			childNode3;
-			childNode3 = childNode3->NextSibling(L"funcNameExpr") )
+			childNode3 = NppXml::nextSiblingElement(childNode3, "funcNameExpr"))
 		{
-			const wchar_t *expr = (childNode3->ToElement())->Attribute(L"expr");
+			const char* expr = NppXml::attribute(childNode3, "expr");
 			if (expr && expr[0])
 				functionNameExprArray.push_back(expr);
 		}
@@ -103,34 +108,39 @@ bool FunctionParsersManager::getZonePaserParameters(TiXmlNode *classRangeParser,
 	return true;
 }
 
-bool FunctionParsersManager::getUnitPaserParameters(TiXmlNode *functionParser, wstring &mainExprStr, std::vector<wstring> &functionNameExprArray, std::vector<wstring> &classNameExprArray)
+bool FunctionParsersManager::getUnitPaserParameters(
+	const NppXml::Element& functionParser,
+	std::string& mainExprStr,
+	std::vector<std::string>& functionNameExprArray,
+	std::vector<std::string>& classNameExprArray
+)
 {
-	const wchar_t *mainExpr = (functionParser->ToElement())->Attribute(L"mainExpr");
+	const char* mainExpr = NppXml::attribute(functionParser, "mainExpr");
 	if (!mainExpr || !mainExpr[0])
 		return false;
 	mainExprStr = mainExpr;
 
-	TiXmlNode *functionNameParser = functionParser->FirstChild(L"functionName");
+	NppXml::Element functionNameParser = NppXml::firstChildElement(functionParser, "functionName");
 	if (functionNameParser)
 	{
-		for (TiXmlNode *childNode = functionNameParser->FirstChildElement(L"nameExpr");
+		for (NppXml::Element childNode = NppXml::firstChildElement(functionNameParser, "nameExpr");
 			childNode;
-			childNode = childNode->NextSibling(L"nameExpr") )
+			childNode = NppXml::nextSiblingElement(childNode, "nameExpr"))
 		{
-			const wchar_t *expr = (childNode->ToElement())->Attribute(L"expr");
+			const char* expr = NppXml::attribute(childNode, "expr");
 			if (expr && expr[0])
 				functionNameExprArray.push_back(expr);
 		}
 	}
 
-	TiXmlNode *classNameParser = functionParser->FirstChild(L"className");
+	NppXml::Element classNameParser = NppXml::firstChildElement(functionParser, "className");
 	if (classNameParser)
 	{
-		for (TiXmlNode *childNode = classNameParser->FirstChildElement(L"nameExpr");
+		for (NppXml::Element childNode = NppXml::firstChildElement(classNameParser, "nameExpr");
 			childNode;
-			childNode = childNode->NextSibling(L"nameExpr") )
+			childNode = NppXml::nextSiblingElement(childNode, "nameExpr"))
 		{
-			const wchar_t *expr = (childNode->ToElement())->Attribute(L"expr");
+			const char* expr = NppXml::attribute(childNode, "expr");
 			if (expr && expr[0])
 				classNameExprArray.push_back(expr);
 		}
@@ -138,10 +148,9 @@ bool FunctionParsersManager::getUnitPaserParameters(TiXmlNode *functionParser, w
 	return true;
 }
 
-
-bool FunctionParsersManager::loadFuncListFromXmlTree(const wstring & xmlDirPath, LangType lType, const wstring& overrideId, int udlIndex)
+bool FunctionParsersManager::loadFuncListFromXmlTree(const std::wstring& xmlDirPath, LangType lType, const std::wstring& overrideId, int udlIndex)
 {
-	wstring funcListRulePath = xmlDirPath;
+	std::wstring funcListRulePath = xmlDirPath;
 	funcListRulePath += L"\\";
 	int index = -1;
 	if (lType == L_USER) // UDL
@@ -160,7 +169,7 @@ bool FunctionParsersManager::loadFuncListFromXmlTree(const wstring & xmlDirPath,
 		index = lType;
 		if (overrideId.empty())
 		{
-			wstring lexerName = ScintillaEditView::_langNameInfoArray[lType]._langName;
+			std::wstring lexerName = ScintillaEditView::_langNameInfoArray[lType]._langName;
 			funcListRulePath += lexerName;
 			funcListRulePath += L".xml";
 		}
@@ -176,108 +185,106 @@ bool FunctionParsersManager::loadFuncListFromXmlTree(const wstring & xmlDirPath,
 	if (_parsers[index] == nullptr)
 		return false;
 
-	TiXmlDocument xmlFuncListDoc(funcListRulePath);
-	bool loadOK = xmlFuncListDoc.LoadFile();
+	NppXml::NewDocument xmlFuncListDoc{};
+	const bool loadOK = NppXml::loadFileFunctionParser(&xmlFuncListDoc, funcListRulePath.c_str());
 
 	if (!loadOK)
 		return false;
 
-	TiXmlNode *root = xmlFuncListDoc.FirstChild(L"NotepadPlus");
+	NppXml::Element root = NppXml::firstChildElement(&xmlFuncListDoc, "NotepadPlus");
 	if (!root)
 		return false;
 
-	root = root->FirstChild(L"functionList");
+	root = NppXml::firstChildElement(root, "functionList");
 	if (!root)
 		return false;
 
-	TiXmlNode *parserRoot = root->FirstChild(L"parser");
+	NppXml::Element parserRoot = NppXml::firstChildElement(root, "parser");
 	if (!parserRoot)
 		return false;
 
-	const wchar_t *id = (parserRoot->ToElement())->Attribute(L"id");
+	const char* id = NppXml::attribute(parserRoot, "id");
 	if (!id || !id[0])
 		return false;
 
-	wstring commentExpr(L"");
-	const wchar_t *pCommentExpr = (parserRoot->ToElement())->Attribute(L"commentExpr");
+	std::string commentExpr;
+	const char* pCommentExpr = NppXml::attribute(parserRoot, "commentExpr");
 	if (pCommentExpr && pCommentExpr[0])
 		commentExpr = pCommentExpr;
 
-	std::vector<wstring> classNameExprArray;
-	std::vector<wstring> functionNameExprArray;
+	std::vector<std::string> classNameExprArray;
+	std::vector<std::string> functionNameExprArray;
 
-	const wchar_t *displayName = (parserRoot->ToElement())->Attribute(L"displayName");
+	const char* displayName = NppXml::attribute(parserRoot, "displayName");
 	if (!displayName || !displayName[0])
 		displayName = id;
 
-	TiXmlNode *classRangeParser = parserRoot->FirstChild(L"classRange");
-	TiXmlNode *functionParser = parserRoot->FirstChild(L"function");
+	NppXml::Element classRangeParser = NppXml::firstChildElement(parserRoot, "classRange");
+	NppXml::Element functionParser = NppXml::firstChildElement(parserRoot, "function");
 	if (classRangeParser && functionParser)
 	{
-		wstring mainExpr, openSymbole, closeSymbole, functionExpr;
+		std::string mainExpr, openSymbole, closeSymbole, functionExpr;
 		getZonePaserParameters(classRangeParser, mainExpr, openSymbole, closeSymbole, classNameExprArray, functionExpr, functionNameExprArray);
 
-		wstring mainExpr2;
-		std::vector<wstring> classNameExprArray2;
-		std::vector<wstring> functionNameExprArray2;
+		std::string mainExpr2;
+		std::vector<std::string> classNameExprArray2;
+		std::vector<std::string> functionNameExprArray2;
 		getUnitPaserParameters(functionParser, mainExpr2, functionNameExprArray2, classNameExprArray2);
-		FunctionUnitParser *funcUnitPaser = new FunctionUnitParser(id, displayName, commentExpr.c_str(), mainExpr2, functionNameExprArray2, classNameExprArray2);
+		auto funcUnitPaser = std::make_unique<FunctionUnitParser>(id, displayName, commentExpr, mainExpr2, functionNameExprArray2, classNameExprArray2);
 
-		_parsers[index]->_parser = new FunctionMixParser(id, displayName, commentExpr.c_str(), mainExpr, openSymbole, closeSymbole, classNameExprArray, functionExpr, functionNameExprArray, funcUnitPaser);
+		_parsers[index]->_parser = std::make_unique<FunctionMixParser>(id, displayName, commentExpr, mainExpr, openSymbole, closeSymbole, classNameExprArray, functionExpr, functionNameExprArray, std::move(funcUnitPaser));
 	}
 	else if (classRangeParser)
 	{
-		wstring mainExpr, openSymbole, closeSymbole, functionExpr;
+		std::string mainExpr, openSymbole, closeSymbole, functionExpr;
 		getZonePaserParameters(classRangeParser, mainExpr, openSymbole, closeSymbole, classNameExprArray, functionExpr, functionNameExprArray);
-		_parsers[index]->_parser = new FunctionZoneParser(id, displayName, commentExpr.c_str(), mainExpr.c_str(), openSymbole.c_str(), closeSymbole.c_str(), classNameExprArray, functionExpr.c_str(), functionNameExprArray);
+		_parsers[index]->_parser = std::make_unique<FunctionZoneParser>(id, displayName, commentExpr, mainExpr, openSymbole, closeSymbole, classNameExprArray, functionExpr, functionNameExprArray);
 	}
 	else if (functionParser)
 	{
-		wstring  mainExpr;
+		std::string mainExpr;
 		getUnitPaserParameters(functionParser, mainExpr, functionNameExprArray, classNameExprArray);
-		_parsers[index]->_parser = new FunctionUnitParser(id, displayName, commentExpr.c_str(), mainExpr.c_str(), functionNameExprArray, classNameExprArray);
+		_parsers[index]->_parser = std::make_unique<FunctionUnitParser>(id, displayName, commentExpr, mainExpr, functionNameExprArray, classNameExprArray);
 	}
 
 	return true;
 }
 
-bool FunctionParsersManager::getOverrideMapFromXmlTree(const wstring & xmlDirPath)
+bool FunctionParsersManager::getOverrideMapFromXmlTree(const std::wstring& xmlDirPath)
 {
-	wstring funcListRulePath = xmlDirPath;
+	std::wstring funcListRulePath = xmlDirPath;
 	funcListRulePath += L"\\overrideMap.xml";
 	
-	TiXmlDocument xmlFuncListDoc(funcListRulePath);
-	bool loadOK = xmlFuncListDoc.LoadFile();
+	NppXml::NewDocument xmlFuncListDoc{};
+	const bool loadOK = NppXml::loadFile(&xmlFuncListDoc, funcListRulePath.c_str());
 
 	if (!loadOK)
 		return false;
 	
-	TiXmlNode *root = xmlFuncListDoc.FirstChild(L"NotepadPlus");
+	NppXml::Element root = NppXml::firstChildElement(&xmlFuncListDoc, "NotepadPlus");
 	if (!root) 
 		return false;
 
-	root = root->FirstChild(L"functionList");
+	root = NppXml::firstChildElement(root, "functionList");
 	if (!root) 
 		return false;
 
-	TiXmlNode *associationMapRoot = root->FirstChild(L"associationMap");
+	NppXml::Element associationMapRoot = NppXml::firstChildElement(root, "associationMap");
 	if (associationMapRoot) 
 	{
-		for (TiXmlNode *childNode = associationMapRoot->FirstChildElement(L"association");
+		for (NppXml::Element childNode = NppXml::firstChildElement(associationMapRoot,"association");
 			childNode;
-			childNode = childNode->NextSibling(L"association") )
+			childNode = NppXml::nextSiblingElement(childNode, "association"))
 		{
-			int langID;
-			const wchar_t *langIDStr = (childNode->ToElement())->Attribute(L"langID", &langID);
-			const wchar_t *id = (childNode->ToElement())->Attribute(L"id");
-			const wchar_t *userDefinedLangName = (childNode->ToElement())->Attribute(L"userDefinedLangName");
-
-			if (!(id && id[0]))
+			const char* id = NppXml::attribute(childNode, "id");
+			if (!id || !id[0])
 				continue;
 
-			if (langIDStr && langIDStr[0])
+			const int langID = NppXml::intAttribute(childNode, "langID", -1);
+			const char* userDefinedLangName = NppXml::attribute(childNode, "userDefinedLangName");
+			if (langID >= 0)
 			{
-				_parsers[langID] = new ParserInfo(id);
+				_parsers[langID] = std::make_unique<ParserInfo>(string2wstring(id));
 			}
 			else if (userDefinedLangName && userDefinedLangName[0])
 			{
@@ -285,7 +292,7 @@ bool FunctionParsersManager::getOverrideMapFromXmlTree(const wstring & xmlDirPat
 
 				if (_currentUDIndex < L_EXTERNAL + nbMaxUserDefined)
 				{
-					_parsers[_currentUDIndex] = new ParserInfo(id, userDefinedLangName);	
+					_parsers[_currentUDIndex] = std::make_unique<ParserInfo>(string2wstring(id), string2wstring(userDefinedLangName));
 				}
 			}
 		}
@@ -294,11 +301,14 @@ bool FunctionParsersManager::getOverrideMapFromXmlTree(const wstring & xmlDirPat
 	return true;
 }
 
-FunctionParser * FunctionParsersManager::getParser(const AssociationInfo & assoInfo)
+FunctionParser* FunctionParsersManager::getParser(const AssociationInfo& assoInfo)
 {
-	const unsigned char doNothing = 0;
-	const unsigned char checkLangID = 1;
-	const unsigned char checkUserDefined = 2;
+	enum ParserType : unsigned char
+	{
+		doNothing,
+		checkLangID,
+		checkUserDefined
+	};
 
 	unsigned char choice = doNothing;
 	// langID != -1 && langID != L_USER
@@ -308,7 +318,7 @@ FunctionParser * FunctionParsersManager::getParser(const AssociationInfo & assoI
 	else if (assoInfo._langID == L_USER && assoInfo._userDefinedLangName != L"")
 		choice = checkUserDefined;
 	else
-		return NULL;
+		return nullptr;
 
 	switch (choice)
 	{
@@ -317,24 +327,22 @@ FunctionParser * FunctionParsersManager::getParser(const AssociationInfo & assoI
 			if (_parsers[assoInfo._langID] != nullptr)
 			{
 				if (_parsers[assoInfo._langID]->_parser != nullptr)
-					return _parsers[assoInfo._langID]->_parser;
-				else
-				{
-					// load it
-					if (loadFuncListFromXmlTree(_xmlDirPath, static_cast<LangType>(assoInfo._langID), _parsers[assoInfo._langID]->_id))
-						return _parsers[assoInfo._langID]->_parser;
-					else if (_xmlDirPath != _xmlDirInstalledPath && !_xmlDirInstalledPath.empty() && loadFuncListFromXmlTree(_xmlDirInstalledPath, static_cast<LangType>(assoInfo._langID), _parsers[assoInfo._langID]->_id))
-						return _parsers[assoInfo._langID]->_parser;
-				}
+					return _parsers[assoInfo._langID]->_parser.get();
+
+				// load it
+				if (loadFuncListFromXmlTree(_xmlDirPath, static_cast<LangType>(assoInfo._langID), _parsers[assoInfo._langID]->_id))
+					return _parsers[assoInfo._langID]->_parser.get();
+				else if (_xmlDirPath != _xmlDirInstalledPath && !_xmlDirInstalledPath.empty() && loadFuncListFromXmlTree(_xmlDirInstalledPath, static_cast<LangType>(assoInfo._langID), _parsers[assoInfo._langID]->_id))
+					return _parsers[assoInfo._langID]->_parser.get();
 			}
 			else
 			{
-				_parsers[assoInfo._langID] = new ParserInfo;
+				_parsers[assoInfo._langID] = std::make_unique<ParserInfo>();
 				// load it
 				if (loadFuncListFromXmlTree(_xmlDirPath, static_cast<LangType>(assoInfo._langID), _parsers[assoInfo._langID]->_id))
-					return _parsers[assoInfo._langID]->_parser;
+					return _parsers[assoInfo._langID]->_parser.get();
 				else if (_xmlDirPath != _xmlDirInstalledPath && !_xmlDirInstalledPath.empty() && loadFuncListFromXmlTree(_xmlDirInstalledPath, static_cast<LangType>(assoInfo._langID), _parsers[assoInfo._langID]->_id))
-					return _parsers[assoInfo._langID]->_parser;
+					return _parsers[assoInfo._langID]->_parser.get();
 
 				return nullptr;
 			}
@@ -352,32 +360,31 @@ FunctionParser * FunctionParsersManager::getParser(const AssociationInfo & assoI
 				{
 					if (_parsers[i]->_parser)
 					{
-						return _parsers[i]->_parser;
-					}
-					else
-					{
-						// load it
-						if (loadFuncListFromXmlTree(_xmlDirPath, static_cast<LangType>(assoInfo._langID), _parsers[i]->_id, i))
-							return _parsers[i]->_parser;
-						else if (_xmlDirPath != _xmlDirInstalledPath && !_xmlDirInstalledPath.empty() && loadFuncListFromXmlTree(_xmlDirInstalledPath, static_cast<LangType>(assoInfo._langID), _parsers[i]->_id, i))
-							return _parsers[i]->_parser;
+						return _parsers[i]->_parser.get();
 					}
 
+					// load it
+					if (loadFuncListFromXmlTree(_xmlDirPath, static_cast<LangType>(assoInfo._langID), _parsers[i]->_id, i))
+						return _parsers[i]->_parser.get();
+					if (_xmlDirPath != _xmlDirInstalledPath && !_xmlDirInstalledPath.empty() && loadFuncListFromXmlTree(_xmlDirInstalledPath, static_cast<LangType>(assoInfo._langID), _parsers[i]->_id, i))
+						return _parsers[i]->_parser.get();
 					break;
 				}
 			}
-
 			return nullptr;
 		}
-		break;
-
 	}
-
 	return nullptr;
 }
 
-
-void FunctionParser::funcParse(std::vector<foundInfo> & foundInfos, size_t begin, size_t end, ScintillaEditView **ppEditView, wstring classStructName, const std::vector< std::pair<size_t, size_t> > * commentZones)
+void FunctionParser::funcParse(
+	std::vector<foundInfo>& foundInfos,
+	size_t begin,
+	size_t end,
+	ScintillaEditView** ppEditView,
+	const std::string& classStructName,
+	const std::vector<std::pair<size_t, size_t>>* commentZones
+)
 {
 	if (begin >= end)
 		return;
@@ -385,32 +392,31 @@ void FunctionParser::funcParse(std::vector<foundInfo> & foundInfos, size_t begin
 	if (_functionExpr.length() == 0)
 		return;
 
-	int flags = SCFIND_REGEXP | SCFIND_POSIX | SCFIND_REGEXP_DOTMATCHESNL;
+	static constexpr int flags = SCFIND_REGEXP | SCFIND_POSIX | SCFIND_REGEXP_DOTMATCHESNL;
 
 	(*ppEditView)->execute(SCI_SETSEARCHFLAGS, flags);
-	intptr_t targetStart = (*ppEditView)->searchInTarget(_functionExpr.c_str(), _functionExpr.length(), begin, end);
-	intptr_t targetEnd = 0;
+	intptr_t targetStart = (*ppEditView)->searchInTarget(_functionExpr, begin, end);
 	
 	//foundInfos.clear();
 	while (targetStart >= 0)
 	{
 		targetStart = (*ppEditView)->execute(SCI_GETTARGETSTART);
-		targetEnd = (*ppEditView)->execute(SCI_GETTARGETEND);
+		intptr_t targetEnd = (*ppEditView)->execute(SCI_GETTARGETEND);
 		if (targetEnd > static_cast<intptr_t>(end)) //we found a result but outside our range, therefore do not process it
 		{
 			break;
 		}
 		size_t foundTextLen = targetEnd - targetStart;
 		if (targetStart + foundTextLen == end)
-            break;
+			break;
 
 		foundInfo fi;
 
 		// dataToSearch & data2ToSearch are optional
 		if (!_functionNameExprArray.size() && !_classNameExprArray.size())
 		{
-			wchar_t foundData[1024] {};
-			(*ppEditView)->getGenericText(foundData, 1024, targetStart, targetEnd);
+			auto foundData = std::string(1024, '\0');
+			(*ppEditView)->getGenericText(foundData.data(), foundData.length(), targetStart, targetEnd);
 
 			fi._data = foundData; // whole found data
 			fi._pos = targetStart;
@@ -439,7 +445,7 @@ void FunctionParser::funcParse(std::vector<foundInfo> & foundInfos, size_t begin
 
 		if (fi._pos != -1 || fi._pos2 != -1) // at least one should be found
 		{
-			if (commentZones != NULL)
+			if (commentZones != nullptr)
 			{
 				if (!isInZones(fi._pos, *commentZones) && !isInZones(fi._pos2, *commentZones))
 					foundInfos.push_back(fi);
@@ -449,32 +455,31 @@ void FunctionParser::funcParse(std::vector<foundInfo> & foundInfos, size_t begin
 		}
 		
 		begin = targetStart + foundTextLen;
-		targetStart = (*ppEditView)->searchInTarget(_functionExpr.c_str(), _functionExpr.length(), begin, end);
+		targetStart = (*ppEditView)->searchInTarget(_functionExpr, begin, end);
 	}
 }
 
 
-wstring FunctionParser::parseSubLevel(size_t begin, size_t end, std::vector< wstring > dataToSearch, intptr_t & foundPos, ScintillaEditView **ppEditView)
+std::string FunctionParser::parseSubLevel(size_t begin, size_t end, std::vector<std::string> dataToSearch, intptr_t& foundPos, ScintillaEditView** ppEditView)
 {
 	if (begin >= end)
 	{
 		foundPos = -1;
-		return wstring();
+		return "";
 	}
 
 	if (!dataToSearch.size())
-		return wstring();
+		return "";
 
-	int flags = SCFIND_REGEXP | SCFIND_POSIX  | SCFIND_REGEXP_DOTMATCHESNL;
+	static constexpr int flags = SCFIND_REGEXP | SCFIND_POSIX  | SCFIND_REGEXP_DOTMATCHESNL;
 
 	(*ppEditView)->execute(SCI_SETSEARCHFLAGS, flags);
-	const wchar_t *regExpr2search = dataToSearch[0].c_str();
-	intptr_t targetStart = (*ppEditView)->searchInTarget(regExpr2search, lstrlen(regExpr2search), begin, end);
+	intptr_t targetStart = (*ppEditView)->searchInTarget(dataToSearch[0], begin, end);
 
 	if (targetStart < 0)
 	{
 		foundPos = -1;
-		return wstring();
+		return "";
 	}
 	intptr_t targetEnd = (*ppEditView)->execute(SCI_GETTARGETEND);
 
@@ -485,15 +490,15 @@ wstring FunctionParser::parseSubLevel(size_t begin, size_t end, std::vector< wst
 	}
 
 	// only one processed element, so we conclude the result
-	wchar_t foundStr[1024];
-	(*ppEditView)->getGenericText(foundStr, 1024, targetStart, targetEnd);
+	auto foundStr = std::string(1024, '\0');
+	(*ppEditView)->getGenericText(foundStr.data(), foundStr.length(), targetStart, targetEnd);
 
 	foundPos = targetStart;
 	return foundStr;
 }
 
 
-bool FunctionParsersManager::parse(std::vector<foundInfo> & foundInfos, const AssociationInfo & assoInfo)
+bool FunctionParsersManager::parse(std::vector<foundInfo>& foundInfos, const AssociationInfo& assoInfo)
 {
 	// Serch the right parser from the given ext in the map
 	FunctionParser *fp = getParser(assoInfo);
@@ -508,7 +513,13 @@ bool FunctionParsersManager::parse(std::vector<foundInfo> & foundInfos, const As
 }
 
 
-size_t FunctionZoneParser::getBodyClosePos(size_t begin, const wchar_t *bodyOpenSymbol, const wchar_t *bodyCloseSymbol, const std::vector< std::pair<size_t, size_t> > & commentZones, ScintillaEditView **ppEditView)
+size_t FunctionZoneParser::getBodyClosePos(
+	size_t begin,
+	const char* bodyOpenSymbol,
+	const char* bodyCloseSymbol,
+	const std::vector<std::pair<size_t, size_t>>& commentZones,
+	ScintillaEditView** ppEditView
+)
 {
 	size_t cntOpen = 1;
 
@@ -517,17 +528,17 @@ size_t FunctionZoneParser::getBodyClosePos(size_t begin, const wchar_t *bodyOpen
 	if (begin >= docLen)
 		return docLen;
 
-	wstring exprToSearch = L"(";
+	std::string exprToSearch = "(";
 	exprToSearch += bodyOpenSymbol;
-	exprToSearch += L"|";
+	exprToSearch += "|";
 	exprToSearch += bodyCloseSymbol;
-	exprToSearch += L")";
+	exprToSearch += ")";
 
 
-	int flags = SCFIND_REGEXP | SCFIND_POSIX | SCFIND_REGEXP_DOTMATCHESNL;
+	static constexpr int flags = SCFIND_REGEXP | SCFIND_POSIX | SCFIND_REGEXP_DOTMATCHESNL;
 
 	(*ppEditView)->execute(SCI_SETSEARCHFLAGS, flags);
-	intptr_t targetStart = (*ppEditView)->searchInTarget(exprToSearch.c_str(), exprToSearch.length(), begin, docLen);
+	intptr_t targetStart = (*ppEditView)->searchInTarget(exprToSearch, begin, docLen);
 	LRESULT targetEnd = 0;
 
 	do
@@ -540,7 +551,7 @@ size_t FunctionZoneParser::getBodyClosePos(size_t begin, const wchar_t *bodyOpen
 			if (!isInZones(targetStart, commentZones))
 			{
 				// Now we determine the symbol (open or close)
-				intptr_t tmpStart = (*ppEditView)->searchInTarget(bodyOpenSymbol, lstrlen(bodyOpenSymbol), targetStart, targetEnd);
+				const intptr_t tmpStart = (*ppEditView)->searchInTarget(bodyOpenSymbol, targetStart, targetEnd);
 				if (tmpStart >= 0) // open symbol found 
 				{
 					++cntOpen;
@@ -557,32 +568,36 @@ size_t FunctionZoneParser::getBodyClosePos(size_t begin, const wchar_t *bodyOpen
 			targetEnd = begin;
 		}
 
-		targetStart = (*ppEditView)->searchInTarget(exprToSearch.c_str(), exprToSearch.length(), targetEnd, docLen);
+		targetStart = (*ppEditView)->searchInTarget(exprToSearch, targetEnd, docLen);
 
 	} while (cntOpen);
 
 	return targetEnd;
 }
 
-void FunctionZoneParser::classParse(vector<foundInfo> & foundInfos, vector< pair<size_t, size_t> > &scannedZones, const std::vector< std::pair<size_t, size_t> > & commentZones, size_t begin, size_t end, ScintillaEditView **ppEditView, wstring /*classStructName*/)
+void FunctionZoneParser::classParse(
+	std::vector<foundInfo>& foundInfos,
+	std::vector<std::pair<size_t, size_t>>& scannedZones,
+	const std::vector<std::pair<size_t, size_t>>& commentZones,
+	size_t begin, size_t end, ScintillaEditView** ppEditView,
+	const std::string& /*classStructName*/
+)
 {
 	if (begin >= end)
 		return;
 
-	int flags = SCFIND_REGEXP | SCFIND_POSIX | SCFIND_REGEXP_DOTMATCHESNL;
+	static constexpr int flags = SCFIND_REGEXP | SCFIND_POSIX | SCFIND_REGEXP_DOTMATCHESNL;
 
 	(*ppEditView)->execute(SCI_SETSEARCHFLAGS, flags);
-	intptr_t targetStart = (*ppEditView)->searchInTarget(_rangeExpr.c_str(), _rangeExpr.length(), begin, end);
-
-	intptr_t targetEnd = 0;
+	intptr_t targetStart = (*ppEditView)->searchInTarget(_rangeExpr, begin, end);
 	
 	while (targetStart >= 0)
 	{
-		targetEnd = (*ppEditView)->execute(SCI_GETTARGETEND);
+		intptr_t targetEnd = (*ppEditView)->execute(SCI_GETTARGETEND);
 
 		// Get class name
 		intptr_t foundPos = 0;
-		wstring subLevelClassStructName = parseSubLevel(targetStart, targetEnd, _classNameExprArray, foundPos, ppEditView);
+		std::string subLevelClassStructName = parseSubLevel(targetStart, targetEnd, _classNameExprArray, foundPos, ppEditView);
 		
 
 		if (!_openSymbole.empty() && !_closeSymbole.empty())
@@ -593,55 +608,54 @@ void FunctionZoneParser::classParse(vector<foundInfo> & foundInfos, vector< pair
 		if (targetEnd > static_cast<intptr_t>(end)) //we found a result but outside our range, therefore do not process it
 			break;
 		
-		scannedZones.push_back(pair<size_t, size_t>(targetStart, targetEnd));
+		scannedZones.push_back(std::pair<size_t, size_t>(targetStart, targetEnd));
 
 		size_t foundTextLen = targetEnd - targetStart;
 		if (targetStart + foundTextLen == end)
-            break;
+			break;
 
 		// Begin to search all method inside
-		//vector< wstring > emptyArray;
+		// std::vector<std::wstring> emptyArray;
 		if (!isInZones(targetStart, commentZones))
 		{
 			funcParse(foundInfos, targetStart, targetEnd, ppEditView, subLevelClassStructName, &commentZones);
 		}
 		begin = targetStart + (targetEnd - targetStart);
-		targetStart = (*ppEditView)->searchInTarget(_rangeExpr.c_str(), _rangeExpr.length(), begin, end);
+		targetStart = (*ppEditView)->searchInTarget(_rangeExpr, begin, end);
 	}
 }
 
 
-void FunctionParser::getCommentZones(vector< pair<size_t, size_t> > & commentZone, size_t begin, size_t end, ScintillaEditView **ppEditView)
+void FunctionParser::getCommentZones(std::vector<std::pair<size_t, size_t>>& commentZone, size_t begin, size_t end, ScintillaEditView** ppEditView)
 {
 	if ((begin >= end) || (_commentExpr.empty()))
 		return;
 
-	int flags = SCFIND_REGEXP | SCFIND_POSIX | SCFIND_REGEXP_DOTMATCHESNL;
+	static constexpr int flags = SCFIND_REGEXP | SCFIND_POSIX | SCFIND_REGEXP_DOTMATCHESNL;
 
 	(*ppEditView)->execute(SCI_SETSEARCHFLAGS, flags);
-	intptr_t targetStart = (*ppEditView)->searchInTarget(_commentExpr.c_str(), _commentExpr.length(), begin, end);
-	intptr_t targetEnd = 0;
+	intptr_t targetStart = (*ppEditView)->searchInTarget(_commentExpr, begin, end);
 	
 	while (targetStart >= 0)
 	{
 		targetStart = (*ppEditView)->execute(SCI_GETTARGETSTART);
-		targetEnd = (*ppEditView)->execute(SCI_GETTARGETEND);
+		intptr_t targetEnd = (*ppEditView)->execute(SCI_GETTARGETEND);
 		if (targetEnd > static_cast<intptr_t>(end)) //we found a result but outside our range, therefore do not process it
 			break;
 
-		commentZone.push_back(pair<size_t, size_t>(targetStart, targetEnd));
+		commentZone.push_back(std::pair<size_t, size_t>(targetStart, targetEnd));
 
 		intptr_t foundTextLen = targetEnd - targetStart;
 		if (targetStart + foundTextLen == static_cast<intptr_t>(end))
-            break;
+			break;
 		
 		begin = targetStart + foundTextLen;
-		targetStart = (*ppEditView)->searchInTarget(_commentExpr.c_str(), _commentExpr.length(), begin, end);
+		targetStart = (*ppEditView)->searchInTarget(_commentExpr, begin, end);
 	}
 }
 
 
-bool FunctionParser::isInZones(size_t pos2Test, const std::vector< std::pair<size_t, size_t>> & zones)
+bool FunctionParser::isInZones(size_t pos2Test, const std::vector<std::pair<size_t, size_t>>& zones)
 {
 	for (size_t i = 0, len = zones.size(); i < len; ++i)
 	{
@@ -652,38 +666,38 @@ bool FunctionParser::isInZones(size_t pos2Test, const std::vector< std::pair<siz
 }
 
 
-void FunctionParser::getInvertZones(vector< pair<size_t, size_t> > &  destZones, const vector< pair<size_t, size_t> > &  sourceZones, size_t begin, size_t end)
+void FunctionParser::getInvertZones(std::vector<std::pair<size_t, size_t>>& destZones, const std::vector<std::pair<size_t, size_t>>& sourceZones, size_t begin, size_t end)
 {
 	if (sourceZones.size() == 0)
 	{
-		destZones.push_back(pair<size_t, size_t>(begin, end));
+		destZones.push_back(std::pair<size_t, size_t>(begin, end));
 	}
 	else
 	{
 		// check the begin
 		if (begin < sourceZones[0].first)
 		{
-			destZones.push_back(pair<size_t, size_t>(begin, sourceZones[0].first - 1));
+			destZones.push_back(std::pair<size_t, size_t>(begin, sourceZones[0].first - 1));
 		}
 
 		size_t i = 0;
 		for (size_t len = sourceZones.size() - 1; i < len; ++i)
 		{
 			size_t newBegin = sourceZones[i].second + 1;
-			size_t newEnd = sourceZones[i+1].first - 1;
+			size_t newEnd = sourceZones[i + 1].first - 1;
 			if (newBegin < newEnd)
-				destZones.push_back(pair<size_t, size_t>(newBegin, newEnd));
+				destZones.push_back(std::pair<size_t, size_t>(newBegin, newEnd));
 		}
 		size_t lastBegin = sourceZones[i].second + 1;
 		if (lastBegin < end)
-			destZones.push_back(pair<size_t, size_t>(lastBegin, end));
+			destZones.push_back(std::pair<size_t, size_t>(lastBegin, end));
 	}
 }
 
 
-void FunctionZoneParser::parse(std::vector<foundInfo> & foundInfos, size_t begin, size_t end, ScintillaEditView **ppEditView, wstring classStructName)
+void FunctionZoneParser::parse(std::vector<foundInfo>& foundInfos, size_t begin, size_t end, ScintillaEditView** ppEditView, const std::string& classStructName)
 {
-	vector< pair<size_t, size_t> > classZones, commentZones, nonCommentZones;
+	std::vector<std::pair<size_t, size_t>> classZones, commentZones, nonCommentZones;
 	getCommentZones(commentZones, begin, end, ppEditView);
 	getInvertZones(nonCommentZones, commentZones, begin, end);
 	for (size_t i = 0, len = nonCommentZones.size(); i < len; ++i)
@@ -692,9 +706,9 @@ void FunctionZoneParser::parse(std::vector<foundInfo> & foundInfos, size_t begin
 	}
 }
 
-void FunctionUnitParser::parse(std::vector<foundInfo> & foundInfos, size_t begin, size_t end, ScintillaEditView **ppEditView, wstring classStructName)
+void FunctionUnitParser::parse(std::vector<foundInfo>& foundInfos, size_t begin, size_t end, ScintillaEditView** ppEditView, const std::string& classStructName)
 {
-	vector< pair<size_t, size_t> > commentZones, nonCommentZones;
+	std::vector<std::pair<size_t, size_t>> commentZones, nonCommentZones;
 	getCommentZones(commentZones, begin, end, ppEditView);
 	getInvertZones(nonCommentZones, commentZones, begin, end);
 	for (size_t i = 0, len = nonCommentZones.size(); i < len; ++i)
@@ -703,20 +717,9 @@ void FunctionUnitParser::parse(std::vector<foundInfo> & foundInfos, size_t begin
 	}
 }
 
-//
-// SortClass for vector<pair<int, int>>
-// sort in _selLpos : increased order
-struct SortZones final
+void FunctionMixParser::parse(std::vector<foundInfo>& foundInfos, size_t begin, size_t end, ScintillaEditView** ppEditView, const std::string& classStructName)
 {
-	bool operator() (const pair<int, int> & l, const pair<int, int> & r)
-	{
-		return (l.first < r.first);
-	}
-};
-
-void FunctionMixParser::parse(std::vector<foundInfo> & foundInfos, size_t begin, size_t end, ScintillaEditView **ppEditView, wstring classStructName)
-{
-	vector< pair<size_t, size_t> > commentZones, scannedZones, nonScannedZones;
+	std::vector<std::pair<size_t, size_t>> commentZones, scannedZones, nonScannedZones;
 	getCommentZones(commentZones, begin, end, ppEditView);
 
 	classParse(foundInfos, scannedZones, commentZones, begin, end, ppEditView, classStructName);
@@ -724,7 +727,7 @@ void FunctionMixParser::parse(std::vector<foundInfo> & foundInfos, size_t begin,
 	// the second level
 	for (size_t i = 0, len = scannedZones.size(); i < len; ++i)
 	{
-		vector< pair<size_t, size_t> > temp;
+		std::vector<std::pair<size_t, size_t>> temp;
 		classParse(foundInfos, temp, commentZones, scannedZones[i].first, scannedZones[i].second, ppEditView, classStructName);
 	}
 	// invert scannedZones
