@@ -22,6 +22,10 @@
 #include "resource.h"
 #include "localization.h"
 
+#include <commctrl.h>
+
+#include "NppConstants.h"
+
 using namespace std;
 
 #define GET_X_LPARAM(lp) static_cast<short>(LOWORD(lp))
@@ -51,22 +55,34 @@ int CALLBACK ListViewCompareProc(LPARAM lParam1, LPARAM lParam2, LPARAM lParamSo
 	return (0 - result);
 }
 
-LRESULT run_listViewProc(WNDPROC oldEditProc, HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
+LRESULT CALLBACK VerticalFileSwitcher::ListViewParentNotifyProc(
+	HWND hWnd,
+	UINT uMsg,
+	WPARAM wParam,
+	LPARAM lParam,
+	UINT_PTR uIdSubclass,
+	[[maybe_unused]] DWORD_PTR /*dwRefData*/
+)
 {
-	switch (message)
+	switch (uMsg)
 	{
+		case WM_NCDESTROY:
+		{
+			::RemoveWindowSubclass(hWnd, VerticalFileSwitcher::ListViewParentNotifyProc, uIdSubclass);
+			break;
+		}
 
 		case WM_MBUTTONUP:
 		{
 			// Redirect the message to parent
-			::SendMessage(::GetParent(hwnd), WM_PARENTNOTIFY, WM_MBUTTONUP, lParam);
-			return TRUE;
+			::SendMessage(::GetParent(hWnd), WM_PARENTNOTIFY, WM_MBUTTONUP, lParam);
+			return 0;
 		}
 
 		default:
 			break;
 	}
-	return ::CallWindowProc(oldEditProc, hwnd, message, wParam, lParam);
+	return ::DefSubclassProc(hWnd, uMsg, wParam, lParam);
 }
 
 void VerticalFileSwitcher::startColumnSort()
@@ -259,16 +275,11 @@ LRESULT CALLBACK VerticalFileSwitcher::FileSwitcherNotifySubclass(
 	return DefSubclassProc(hWnd, uMsg, wParam, lParam);
 }
 
-void VerticalFileSwitcher::autoSubclassWindowNotify(HWND hParent)
-{
-	::SetWindowSubclass(hParent, VerticalFileSwitcher::FileSwitcherNotifySubclass, _fileSwitcherNotifySubclassID, 0);
-}
-
 intptr_t CALLBACK VerticalFileSwitcher::run_dlgProc(UINT message, WPARAM wParam, LPARAM lParam)
 {
 	switch (message)
 	{
-		case WM_INITDIALOG :
+		case WM_INITDIALOG:
 		{
 			VerticalFileSwitcher::initPopupMenus();
 
@@ -276,11 +287,9 @@ intptr_t CALLBACK VerticalFileSwitcher::run_dlgProc(UINT message, WPARAM wParam,
 			_fileListView.initList();
 			_fileListView.display();
 
-			::SetWindowLongPtr(_fileListView.getHSelf(), GWLP_USERDATA, reinterpret_cast<LONG_PTR>(this));
-			_defaultListViewProc = reinterpret_cast<WNDPROC>(::SetWindowLongPtr(_fileListView.getHSelf(), GWLP_WNDPROC, reinterpret_cast<LONG_PTR>(listViewStaticProc)));
-
 			NppDarkMode::autoSubclassAndThemeChildControls(_hSelf);
-			VerticalFileSwitcher::autoSubclassWindowNotify(_hSelf);
+			::SetWindowSubclass(_hSelf, VerticalFileSwitcher::FileSwitcherNotifySubclass, static_cast<UINT_PTR>(SubclassID::first), 0);
+			::SetWindowSubclass(_fileListView.getHSelf(), VerticalFileSwitcher::ListViewParentNotifyProc, static_cast<UINT_PTR>(SubclassID::first), 0);
 
 			return TRUE;
 		}
@@ -295,7 +304,7 @@ intptr_t CALLBACK VerticalFileSwitcher::run_dlgProc(UINT message, WPARAM wParam,
 		// So we subclass listview to redirect WM_MBUTTONUP via WM_PARENTNOTIFY (as WM_MBUTTONDOWN)
 		case WM_PARENTNOTIFY:
 		{
-			switch ( wParam )
+			switch (wParam)
 			{
 				case WM_MBUTTONUP:
 				{
@@ -313,9 +322,9 @@ intptr_t CALLBACK VerticalFileSwitcher::run_dlgProc(UINT message, WPARAM wParam,
 						// Get the actual item info from the ID
 						LVITEM item{};
 						item.mask = LVIF_PARAM;
-						item.iItem = hitInfo.iItem;	
+						item.iItem = hitInfo.iItem;
 						ListView_GetItem(_fileListView.getHSelf(), &item);
-						TaskLstFnStatus *tlfs = (TaskLstFnStatus *)item.lParam;
+						auto* tlfs = reinterpret_cast<TaskLstFnStatus*>(item.lParam);
 
 						// Close the document
 						closeDoc(tlfs);
