@@ -23,7 +23,7 @@
 struct RecentItem {
 	int _id = 0;
 	std::wstring _name;
-	explicit RecentItem(const wchar_t * name) : _name(name) {};
+	explicit RecentItem(const wchar_t* name) : _name(name) {}
 };
 
 typedef std::deque<RecentItem> recentList;
@@ -33,7 +33,7 @@ class LastRecentFileList
 public:
 	LastRecentFileList() {
 		_userMax = (NppParameters::getInstance()).getNbMaxRecentFile();
-	};
+	}
 
 	void initMenu(HMENU hMenu, int idBase, int posBase, Accelerator *accelerator, bool doSubMenu = false);
 	void switchMode();
@@ -46,16 +46,15 @@ public:
 
 	int getSize() {
 		return _size;
-	};
+	}
 
-
-	int getMaxNbLRF() const {
+	static int getMaxNbLRF() {
 		return NB_MAX_LRF_FILE;
-	};
+	}
 
 	int getUserMaxNbLRF() const {
 		return _userMax;
-	};
+	}
 
 	std::wstring & getItem(int id);	//use menu id
 	std::wstring & getIndex(int index);	//use menu id
@@ -64,7 +63,7 @@ public:
 		if (_lrfl.size() == 0)
 			return L"";
 		return _lrfl.front()._name;
-	};
+	}
 
 	void setUserMaxNbLRF(int size);
 
@@ -72,15 +71,15 @@ public:
 
 	void setLock(bool lock) {
 		_locked = lock;
-	};
+	}
 
 	void setLangEncoding(int nativeLangEncoding) {
 		_nativeLangEncoding = nativeLangEncoding;
-	};
+	}
 
 	bool isSubMenuMode() const {
 		return (_hParentMenu != NULL);
-	};
+	}
 
 private:
 	recentList _lrfl;
@@ -102,4 +101,3 @@ private:
 	int popFirstAvailableID();
 	void setAvailable(int id);
 };
-
